==> haskell-data-default-instances-old-locale-0.0.1-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default-instances-old-locale.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-default-instances-old-locale
version:              0.0.1
visibility:           public
id:
    data-default-instances-old-locale-0.0.1-BSBT71snpgVEb2Ithyw9MK

key:
    data-default-instances-old-locale-0.0.1-BSBT71snpgVEb2Ithyw9MK

license:              BSD-3-Clause
maintainer:           <l.mai@web.de>
author:               Lukas Mai
synopsis:             Default instances for types in old-locale
category:             Data
abi:                  fb623779a11fdf5c90f66f2f72f61b99
exposed:              True
exposed-modules:      Data.Default.Instances.OldLocale
import-dirs:
    /usr/lib/ghc-8.8.3/site-local/data-default-instances-old-locale-0.0.1

library-dirs:
    /usr/lib/ghc-8.8.3/site-local/data-default-instances-old-locale-0.0.1

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.8.3/data-default-instances-old-locale-0.0.1

hs-libraries:
    HSdata-default-instances-old-locale-0.0.1-BSBT71snpgVEb2Ithyw9MK

depends:
    base-4.13.0.0 data-default-class-0.1.2.0-3WblArvKItDIiwkDl9AciG
    old-locale-1.0.0.7-KOGgqu8HfWChZyQBUEp1c

haddock-interfaces:
    /usr/share/doc/haskell-data-default-instances-old-locale/html/data-default-instances-old-locale.haddock

haddock-html:
    /usr/share/doc/haskell-data-default-instances-old-locale/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-default-instances-old-locale-0.0.1-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default-instances-old-locale.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-default-instances-old-locale
version:              0.0.1
visibility:           public
id:
    data-default-instances-old-locale-0.0.1-4IrohixuakE85UjUYK7Xo5

key:
    data-default-instances-old-locale-0.0.1-4IrohixuakE85UjUYK7Xo5

license:              BSD-3-Clause
maintainer:           <l.mai@web.de>
author:               Lukas Mai
synopsis:             Default instances for types in old-locale
category:             Data
abi:                  471120758b32e001b9616940de04493a
exposed:              True
exposed-modules:      Data.Default.Instances.OldLocale
import-dirs:
    /usr/lib/ghc-8.10.2/site-local/data-default-instances-old-locale-0.0.1

library-dirs:
    /usr/lib/ghc-8.10.2/site-local/data-default-instances-old-locale-0.0.1

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.2/data-default-instances-old-locale-0.0.1

hs-libraries:
    HSdata-default-instances-old-locale-0.0.1-4IrohixuakE85UjUYK7Xo5

depends:
    base-4.14.1.0 data-default-class-0.1.2.0-56BXPST0gStFZdhRwxhsn8
    old-locale-1.0.0.7-LpTuchyagHAP7STZdm71P

haddock-interfaces:
    /usr/share/doc/haskell-data-default-instances-old-locale/html/data-default-instances-old-locale.haddock

haddock-html:
    /usr/share/doc/haskell-data-default-instances-old-locale/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
